// Copyright 2002 Adam Megacz, see the COPYING file for licensing [GPL]
package org.xwt;

import org.xwt.js.*;
import org.xwt.util.*;

/** implements objects in the xwt.static.* namespace */
public class Static extends JS.Scope {

    public static Static getStatic(String resourcename) {
        Template t = Template.getTemplate(resourcename, null);
        if (t != null) t.link();
        return (Static)cache.get(resourcename);
    }

    public static Static createStatic(String resourcename, boolean isPackage) {
        Static ret = (Static)cache.get(resourcename);
        if (ret != null) return ret;
        if (resourcename.indexOf('.') != -1)
            createStatic(resourcename.substring(0, resourcename.lastIndexOf('.')), true);
        ret = new Static(resourcename, isPackage);
        return ret;
    }

    private static Hash cache = new Hash();

    /** the resource name that this Static object corresponds to */
    private String resourcename = null;

    /** true iff this represents a directory (rather than an actual xwt) */
    public boolean ispackage = false;

    private Static(String resourcename, boolean ispackage) {
        super(null);
        cache.put(resourcename, this);
        this.resourcename = resourcename;
        this.ispackage = ispackage;
        setSeal(ispackage);
    }
    
    /** creates a new static representing a package */
    public Static(String resourcename) { this(resourcename, true); }

    public Object get(Object name_) {
        String name = name_.toString();
        if (!ispackage) return super.get(name);
        return getStatic(resourcename + (resourcename.length() == 0 ? "" : ".") + name);
    }

    static { createStatic("", true); }

}
